(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     61718,       1639]*)
(*NotebookOutlinePosition[     62420,       1663]*)
(*  CellTagsIndexPosition[     62376,       1659]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Note-10"
}], "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Lagrangian and Rayleigh's dissipative function in linear motion system\
\>", "Subsubsection"],

Cell["Kinetic energy:", "Text"],

Cell[BoxData[
    \(\(kineticEnergy[m_, x_] := \((1/2)\)*m*\((D[x[t], t]^2)\);\)\)], "Input"],

Cell["Potential energy:", "Text"],

Cell[BoxData[
    \(\(potentialEnergy[k_, x_] := \((1/2)\)*k*\((x[t]^2)\);\)\)], "Input"],

Cell["Lagrangian:", "Text"],

Cell[BoxData[
    \(\(l[m_, k_, x_] := 
        kineticEnergy[m, x] - potentialEnergy[k, x];\)\)], "Input"],

Cell["Rayleigh dissipative function:", "Text"],

Cell[BoxData[
    \(\(f[b_, x_] := \((1/2)\)*b*\((D[x[t], t]^2)\);\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["System of equations", "Subsubsection"],

Cell["Linear motion system:", "Text"],

Cell[BoxData[
    \(equ[M_, K_, B_] := 
      D[D[l[M, K, x], D[x[t], t]], t] - D[l[M, K, x], x[t]] + 
        D[f[B, x], D[x[t], t]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution of Inhomogeneous Equation", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solution = DSolve[equ[M, K, B] \[Equal] Qdc, x[t], t]\)], "Input"],

Cell[BoxData[
    \({{x[t] \[Rule] 
          Qdc\/K + \[ExponentialE]\^\(\(\((\(-B\) - \@\(B\^2 - 4\ K\ M\))\)\ \
t\)\/\(2\ M\)\)\ C[
                1] + \[ExponentialE]\^\(\(\((\(-B\) + \@\(B\^2 - 4\ K\ M\))\)\
\ t\)\/\(2\ M\)\)\ C[2]}}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simple Dumping", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B = 2\ Sqrt[K\ M];\)\), "\[IndentingNewLine]", 
    \(solution = DSolve[equ[M, K, B] \[Equal] Qdc, x[t], t]\)}], "Input"],

Cell[BoxData[
    \({{x[t] \[Rule] 
          Qdc\/K + \[ExponentialE]\^\(-\(\(\@\(K\ M\)\ t\)\/M\)\)\ C[
                1] + \[ExponentialE]\^\(-\(\(\@\(K\ M\)\ t\)\/M\)\)\ t\ C[
                2]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Qdc = 5. ;\)\), "\[IndentingNewLine]", 
    \(\(K = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(M = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(Con[1] = \(-Qdc\)/K;\)\), "\[IndentingNewLine]", 
    \(\(Con[2] = 0. ;\)\), "\[IndentingNewLine]", 
    \(\(B = 2\ Sqrt[K\ M];\)\), "\[IndentingNewLine]", 
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] Qdc, x[t], t, 
        GeneratedParameters \[Rule] Con]\)}], "Input"],

Cell[BoxData[
    \({{x[t] \[Rule] \(\(10.`\)\(\[InvisibleSpace]\)\) - 
            10.`\ \[ExponentialE]\^\(\(-0.5773502691896262`\)\ t\) + 
            0.`\ \[ExponentialE]\^\(\(-0.5773502691896253`\)\ t\)}}\)], \
"Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[x[t] /. solution], {t, 0, 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.0590439 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .1328 -6 -4.5 ]
[.01131 .1328 0 4.5 ]
[.01131 .25089 -6 -4.5 ]
[.01131 .25089 0 4.5 ]
[.01131 .36898 -6 -4.5 ]
[.01131 .36898 0 4.5 ]
[.01131 .48707 -6 -4.5 ]
[.01131 .48707 0 4.5 ]
[.01131 .60515 -12 -4.5 ]
[.01131 .60515 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .1328 m
.03006 .1328 L
s
[(2)] .01131 .1328 1 0 Mshowa
.02381 .25089 m
.03006 .25089 L
s
[(4)] .01131 .25089 1 0 Mshowa
.02381 .36898 m
.03006 .36898 L
s
[(6)] .01131 .36898 1 0 Mshowa
.02381 .48707 m
.03006 .48707 L
s
[(8)] .01131 .48707 1 0 Mshowa
.02381 .60515 m
.03006 .60515 L
s
[(10)] .01131 .60515 1 0 Mshowa
.125 Mabswid
.02381 .04424 m
.02756 .04424 L
s
.02381 .07376 m
.02756 .07376 L
s
.02381 .10328 m
.02756 .10328 L
s
.02381 .16232 m
.02756 .16232 L
s
.02381 .19185 m
.02756 .19185 L
s
.02381 .22137 m
.02756 .22137 L
s
.02381 .28041 m
.02756 .28041 L
s
.02381 .30993 m
.02756 .30993 L
s
.02381 .33946 m
.02756 .33946 L
s
.02381 .3985 m
.02756 .3985 L
s
.02381 .42802 m
.02756 .42802 L
s
.02381 .45754 m
.02756 .45754 L
s
.02381 .51659 m
.02756 .51659 L
s
.02381 .54611 m
.02756 .54611 L
s
.02381 .57563 m
.02756 .57563 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .138 L
.10458 .24331 L
.14415 .32048 L
.18221 .37913 L
.22272 .42835 L
.26171 .46557 L
.30316 .49658 L
.34309 .51992 L
.3815 .53763 L
.42237 .55245 L
.46172 .56363 L
.49955 .57214 L
.53984 .5793 L
.57861 .58471 L
.61984 .58923 L
.65954 .59264 L
.69774 .59523 L
.73838 .59739 L
.77751 .59903 L
.81909 .6004 L
.85916 .60142 L
.89771 .6022 L
.93871 .60285 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00A03oool400000380oooo0`00000^0?ooo`<00000<P3oool2000002h0oooo1@0000020?oo
o`8000001`3oool004@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0]0?ooo`04
0000003oool0oooo00000300oooo00@000000?ooo`3oool00000;`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0103oool004D0oooo00<000000?ooo`3oool0<03oool5
000002h0oooo00@000000?ooo`3oool00000<03oool010000000oooo0?ooo`00000_0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`00AP3oool00`000000oooo
0?ooo`0_0?ooo`040000003oool0oooo000002l0oooo0`00000b0?ooo`800000<03oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103oool004@0oooo00@000000?ooo`3o
ool00000<@3oool00`000000oooo0000000`0?ooo`030000003oool0oooo0300oooo00@000000?oo
o`3oool00000;`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0103o
ool004D0oooo0P00000c0?ooo`800000<03oool300000340oooo0P00000_0?ooo`800000103oool2
000000L0oooo003o0?ooob40oooo000B0?ooo`030000003oool0oooo0?l0oooo303oool00180oooo
00<000000?ooo`3oool0o`3oool<0?ooo`004P3oool00`000000oooo0?ooo`3o0?ooo``0oooo000B
0?ooo`030000003oool0oooo0?l0oooo303oool000`0ooooo`00000A000000@0oooo000B0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`00
4P3oool200000380oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`080?ooo`004P3o
ool200000?l0oooo3@3oool00180oooo0P00003o0?ooo`d0oooo000B0?ooo`030000003oool00000
0?l0oooo303oool00180oooo00<000000?ooo`000000o`3oool<0?ooo`004P3oool00`000000oooo
0000003o0?ooo``0oooo000B0?ooo`80000000<0oooo0000003oool0o`3oool:0?ooo`004P3oool0
10000000oooo0?ooo`00003o0?ooo`/0oooo000B0?ooo`040000003oool0oooo00000?l0oooo2`3o
ool00180oooo00D000000?ooo`3oool0oooo0000003o0?ooo`X0oooo000B0?ooo`050000003oool0
oooo0?ooo`000000o`3oool:0?ooo`004P3oool01@000000oooo0?ooo`3oool000000?l0oooo2P3o
ool00180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`L0oooo000B0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool70?ooo`004P3oool2000000<0
oooo00<000000?ooo`3oool0o`3oool70?ooo`004P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0?l0oooo1P3oool00180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3o0?ooo`H0oooo000B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool6
0?ooo`004P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo1@3oool00180
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooo`D0oooo000B0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0o`3oool50?ooo`004P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0?l0oooo103oool00180oooo0P0000060?ooo`030000003oool0
oooo0?l0oooo103oool00180oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oo
o`@0oooo000B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3oool30?ooo`00
4P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo0`3oool00180oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000B0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0o`3oool20?ooo`002P3oool4000000@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`3o0?ooo`80oooo000:0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooo`80oooo000;0?ooo`030000
003oool0oooo00@0oooo0`0000080?ooo`030000003oool0oooo0?l0oooo0@3oool000`0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo0@3o
ool000X0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0?l0oooo0@3oool000/0oooo0P0000050?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0o`3oool00180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oo
o`004P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?h0oooo000B0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0oP3oool00180oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`3n0?ooo`004P3oool2000000`0oooo00<000000?ooo`3oool0o@3oool0
0180oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3m0?ooo`004P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0?d0oooo000B0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0o03oool00180oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`3l0?ooo`004P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?/0oooo000B0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0n`3oool00180oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`3k0?ooo`004P3oool2000000l0oooo00<000000?ooo`3oool0
nP3oool00180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3j0?ooo`004P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?X0oooo000B0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0n@3oool00180oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`3i0?ooo`004P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?P0oooo
000B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0n03oool00180oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`3h0?ooo`004P3oool200000180oooo00<000000?oo
o`3oool0m`3oool00180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3g0?ooo`00
4P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?L0oooo000B0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0mP3oool00180oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3f0?ooo`004P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0?D0oooo000<0?ooo`<000000`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?D0
oooo000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`3d0?ooo`002P3oool5000000<0oooo0`00000D0?ooo`030000003oool0oooo0?@0oooo000:
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`3c0?ooo`002`3oool00`000000oooo000000040?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0l`3oool000`0oooo0P0000040?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0lP3oool00180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3b0?ooo`00
4P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0?40oooo000B0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0l@3oool00180oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`3`0?ooo`004P3oool2000001T0oooo00<000000?ooo`3oool0l03oool00180
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3_0?ooo`004P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo0>l0oooo000B0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0kP3oool00180oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3^
0?ooo`004P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0>d0oooo000B0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0k@3oool00180oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`3/0?ooo`004P3oool2000001d0oooo00<000000?ooo`3oool0k03o
ool00180oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3[0?ooo`004P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0>/0oooo000B0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0jP3oool00180oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`3Y0?ooo`004P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0>T0oooo000B
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0j03oool00180oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`3X0?ooo`004P3oool200000280oooo00<000000?ooo`3o
ool0i`3oool00180oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`3V0?ooo`004P3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0>H0oooo000B0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0i@3oool00180oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`3T0?ooo`004P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0>@0
oooo000:0?ooo`<000001@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0><0oooo
000:0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`3S0?ooo`002P3oool010000000oooo0?ooo`0000040?ooo`<000009P3oool00`000000oooo
0?ooo`3R0?ooo`002P3oool3000000D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`3Q0?ooo`002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0h@3oool000/0oooo0`0000040?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0h03oool00180oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3O0?ooo`00
4P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0=h0oooo000B0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0g@3oool00180oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`3M0?ooo`004P3oool2000002d0oooo00<000000?ooo`3oool0g03oool00180
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3K0?ooo`004P3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0=X0oooo000B0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0f@3oool00180oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3H
0?ooo`004P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0=P0oooo000B0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0e`3oool00180oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`3F0?ooo`004P3oool2000003@0oooo00<000000?ooo`3oool0e@3o
ool00180oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3D0?ooo`004P3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo0=<0oooo000B0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0dP3oool00180oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`3A0?ooo`004P3oool00`000000oooo0?ooo`0h0?ooo`800000d@3oool00180oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`3>0?ooo`004P3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo0<d0oooo000B0?ooo`800000?@3oool00`000000oooo0?ooo`3<0?ooo`00
4P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0</0oooo000B0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool0bP3oool00180oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`390?ooo`004P3oool00`000000oooo0?ooo`100?ooo`800000b@3oool00180
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`360?ooo`002`3oool2000000D0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`350?ooo`002P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0a03oool000X0oooo00@0
00000?ooo`3oool00000103oool3000004D0oooo00<000000?ooo`3oool0``3oool000/0oooo0P00
00050?ooo`030000003oool0oooo04H0oooo0P0000330?ooo`002P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0`03oool000/0oooo0P000005
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0_`3oool00180oooo00<000000?oo
o`3oool0BP3oool200000;l0oooo000B0?ooo`030000003oool0oooo04`0oooo0P00002m0?ooo`00
4P3oool00`000000oooo0?ooo`1>0?ooo`800000^`3oool00180oooo00<000000?ooo`3oool0D03o
ool200000;T0oooo000B0?ooo`800000D`3oool200000;L0oooo000B0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool0]03oool00180oooo00<000000?ooo`3oool0E@3oool200000;@0
oooo000B0?ooo`030000003oool0oooo05L0oooo0P00002b0?ooo`004P3oool00`000000oooo0?oo
o`1I0?ooo`800000/03oool00180oooo00<000000?ooo`3oool0F`3oool200000:h0oooo000B0?oo
o`030000003oool0oooo05d0oooo0`00002[0?ooo`004P3oool00`000000oooo0?ooo`1P0?ooo`<0
0000Z03oool00180oooo0P00001T0?ooo`800000YP3oool00180oooo00<000000?ooo`3oool0I@3o
ool300000:<0oooo000B0?ooo`030000003oool0oooo06P0oooo0`00002P0?ooo`004P3oool00`00
0000oooo0?ooo`1[0?ooo`@00000W03oool00180oooo00<000000?ooo`3oool0K`3oool4000009P0
oooo000B0?ooo`030000003oool0oooo07<0oooo1000002D0?ooo`004P3oool00`000000oooo0?oo
o`1g0?ooo`D00000S`3oool00180oooo00<000000?ooo`3oool0O03oool5000008X0oooo000B0?oo
o`800000PP3oool6000008@0oooo000B0?ooo`030000003oool0oooo08L0oooo2000001l0?ooo`00
4P3oool00`000000oooo0?ooo`2?0?ooo`P00000M03oool00180oooo00<000000?ooo`3oool0U`3o
ool6000006h0oooo000B0?ooo`030000003oool0oooo09d0oooo2000001V0?ooo`004P3oool00`00
0000oooo0?ooo`2U0?oooaD00000D@3oool000@0oooo1@0000020?ooo`8000001@3oool00`000000
oooo0?ooo`2j0?oooaH00000>`3oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0d03oool[00000100oooo00060?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000n`3oool6000000X0
oooo00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0?l0oooo303oool000H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool<0?ooo`001@3oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo0?l0oooo303oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.731575, -0.773999, \
0.0387355, 0.0624805}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simple Dumping with Two Characteristic Values", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B = 1 + 2\ Sqrt[K\ M];\)\), "\[IndentingNewLine]", 
    \(solution = DSolve[equ[M, K, B] \[Equal] Qdc, x[t], t]\)}], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \(\(10.`\)\(\[InvisibleSpace]\)\) + \
\[ExponentialE]\^\(\(-1.6149642927103738`\)\ t\)\ C[
                1] + \[ExponentialE]\^\(\(-0.2064029123355441`\)\ t\)\ C[
                2]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(K = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(M = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(B = 1 + 2\ Sqrt[K\ M];\)\), "\[IndentingNewLine]", 
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] Qdc, x[t], t, 
        GeneratedParameters \[Rule] Con]\)}], "Input"],

Cell[BoxData[
    \({{x[t] \[Rule] \(\(10.`\)\(\[InvisibleSpace]\)\) - 
            10.`\ \[ExponentialE]\^\(\(-1.6149642927103738`\)\ t\) + 
            0.`\ \[ExponentialE]\^\(\(-0.2064029123355441`\)\ t\)}}\)], \
"Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[x[t] /. solution], {t, 0, 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -2.92796 0.353128 [
[.21429 .23769 -3 -9 ]
[.21429 .23769 3 0 ]
[.40476 .23769 -3 -9 ]
[.40476 .23769 3 0 ]
[.59524 .23769 -3 -9 ]
[.59524 .23769 3 0 ]
[.78571 .23769 -3 -9 ]
[.78571 .23769 3 0 ]
[.97619 .23769 -6 -9 ]
[.97619 .23769 6 0 ]
[.01131 .07363 -18 -4.5 ]
[.01131 .07363 0 4.5 ]
[.01131 .16191 -24 -4.5 ]
[.01131 .16191 0 4.5 ]
[.01131 .33847 -24 -4.5 ]
[.01131 .33847 0 4.5 ]
[.01131 .42676 -18 -4.5 ]
[.01131 .42676 0 4.5 ]
[.01131 .51504 -24 -4.5 ]
[.01131 .51504 0 4.5 ]
[.01131 .60332 -12 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .25019 m
.21429 .25644 L
s
[(2)] .21429 .23769 0 1 Mshowa
.40476 .25019 m
.40476 .25644 L
s
[(4)] .40476 .23769 0 1 Mshowa
.59524 .25019 m
.59524 .25644 L
s
[(6)] .59524 .23769 0 1 Mshowa
.78571 .25019 m
.78571 .25644 L
s
[(8)] .78571 .23769 0 1 Mshowa
.97619 .25019 m
.97619 .25644 L
s
[(10)] .97619 .23769 0 1 Mshowa
.125 Mabswid
.07143 .25019 m
.07143 .25394 L
s
.11905 .25019 m
.11905 .25394 L
s
.16667 .25019 m
.16667 .25394 L
s
.2619 .25019 m
.2619 .25394 L
s
.30952 .25019 m
.30952 .25394 L
s
.35714 .25019 m
.35714 .25394 L
s
.45238 .25019 m
.45238 .25394 L
s
.5 .25019 m
.5 .25394 L
s
.54762 .25019 m
.54762 .25394 L
s
.64286 .25019 m
.64286 .25394 L
s
.69048 .25019 m
.69048 .25394 L
s
.7381 .25019 m
.7381 .25394 L
s
.83333 .25019 m
.83333 .25394 L
s
.88095 .25019 m
.88095 .25394 L
s
.92857 .25019 m
.92857 .25394 L
s
.25 Mabswid
0 .25019 m
1 .25019 L
s
.02381 .07363 m
.03006 .07363 L
s
[(8.5)] .01131 .07363 1 0 Mshowa
.02381 .16191 m
.03006 .16191 L
s
[(8.75)] .01131 .16191 1 0 Mshowa
.02381 .33847 m
.03006 .33847 L
s
[(9.25)] .01131 .33847 1 0 Mshowa
.02381 .42676 m
.03006 .42676 L
s
[(9.5)] .01131 .42676 1 0 Mshowa
.02381 .51504 m
.03006 .51504 L
s
[(9.75)] .01131 .51504 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(10)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .09128 m
.02756 .09128 L
s
.02381 .10894 m
.02756 .10894 L
s
.02381 .1266 m
.02756 .1266 L
s
.02381 .14425 m
.02756 .14425 L
s
.02381 .17957 m
.02756 .17957 L
s
.02381 .19722 m
.02756 .19722 L
s
.02381 .21488 m
.02756 .21488 L
s
.02381 .23253 m
.02756 .23253 L
s
.02381 .26785 m
.02756 .26785 L
s
.02381 .2855 m
.02756 .2855 L
s
.02381 .30316 m
.02756 .30316 L
s
.02381 .32082 m
.02756 .32082 L
s
.02381 .35613 m
.02756 .35613 L
s
.02381 .37379 m
.02756 .37379 L
s
.02381 .39144 m
.02756 .39144 L
s
.02381 .4091 m
.02756 .4091 L
s
.02381 .44441 m
.02756 .44441 L
s
.02381 .46207 m
.02756 .46207 L
s
.02381 .47972 m
.02756 .47972 L
s
.02381 .49738 m
.02756 .49738 L
s
.02381 .53269 m
.02756 .53269 L
s
.02381 .55035 m
.02756 .55035 L
s
.02381 .56801 m
.02756 .56801 L
s
.02381 .58566 m
.02756 .58566 L
s
.02381 .05597 m
.02756 .05597 L
s
.02381 .03831 m
.02756 .03831 L
s
.02381 .02066 m
.02756 .02066 L
s
.02381 .003 m
.02756 .003 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.12842 0 m
.14357 .13993 L
.16272 .2684 L
.1835 .36787 L
.20334 .43513 L
.22437 .48558 L
.2439 .51878 L
.2622 .54133 L
.28245 .55935 L
.30098 .5712 L
.31996 .58004 L
.34068 .58694 L
.36036 .59158 L
.38133 .5951 L
.39162 .59641 L
.40274 .5976 L
.42291 .59926 L
.44285 .60042 L
.46392 .60129 L
.48355 .60187 L
.50189 .60225 L
.52224 .60257 L
.5408 .60277 L
.55988 .60292 L
.58064 .60304 L
.60042 .60312 L
.62142 .60318 L
.64089 .60322 L
.65917 .60325 L
.67936 .60327 L
.69786 .60328 L
.71679 .60329 L
.73749 .6033 L
.7571 .60331 L
.77805 .60331 L
.78829 .60331 L
.79939 .60331 L
.81954 .60331 L
.83942 .60332 L
.86046 .60332 L
.88004 .60332 L
.89835 .60332 L
.91864 .60332 L
.93717 .60332 L
.95584 .60332 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`006`3oool2000001X0oooo00<000000?ooo`3oool0iP3oool001/0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`3V0?ooo`006`3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0>H0oooo000K0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0iP3o
ool001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3V0?ooo`006`3oool20000
01/0oooo00<000000?ooo`3oool0i@3oool001/0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`3U0?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0>D0oooo
000K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0i@3oool001/0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`3U0?ooo`006`3oool2000001/0oooo00<000000?oo
o`3oool0i@3oool001/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3U0?ooo`00
6`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0>D0oooo000K0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0i@3oool001/0oooo0P00000L0?ooo`030000003oool0
oooo0>@0oooo000K0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0i03oool001/0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3T0?ooo`00203oool2000000@0oooo
0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0>@0oooo
00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0>@0oooo00070?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`3oool00P3oool2000001`0oooo00<000000?ooo`3oool0i03oool000P0oooo
0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0>@0oooo
00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo0>@0oooo00080?ooo`8000002P3oool3000000@0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`3T0?ooo`006`3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo0>@0oooo000K0?ooo`8000007@3oool00`000000oooo0?ooo`3S0?oo
o`006`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0><0oooo000K0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0h`3oool001/0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`3S0?ooo`006`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0><0oooo000K0?ooo`8000007@3oool00`000000oooo0?ooo`3S0?ooo`006`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo0><0oooo000K0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0h`3oool001/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`3S0?ooo`006`3oool2000001h0oooo00<000000?ooo`3oool0hP3oool001/0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`3R0?ooo`006`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0>80oooo000K0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
hP3oool001/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3R0?ooo`006`3oool2
000001h0oooo00<000000?ooo`3oool0hP3oool001/0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`3R0?ooo`006`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0>80
oooo00020?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool00P3oool2000000D0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3Q0?ooo`0000D0oooo0000003oool0oooo
0000000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0h@3oool000050?ooo`000000oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P00000O0?ooo`03
0000003oool0oooo0>40oooo00020?ooo`800000303oool010000000oooo0?ooo`3oool2000000D0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3Q0?ooo`0000D0oooo0000003oool0
oooo000000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0>40oooo00020?ooo`8000002@3oool4000000<0
oooo0`0000040?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0h@3oool001/0oooo
0P00000O0?ooo`030000003oool0oooo0>40oooo000K0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0h03oool001/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3P
0?ooo`006`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0>00oooo000K0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0h03oool001/0oooo0P00000P0?ooo`030000
003oool0oooo0>00oooo000K0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0h03o
ool001/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3P0?ooo`006`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo1000000a0?ooo`<00000;P3oool30000
0300oooo0P00000]0?ooo`D000000P3oool2000000@0oooo000K0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02d0
oooo00@000000?ooo`3oool00000;P3oool010000000oooo0?ooo`00000^0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`010?ooo`006`3oool200000240oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0_0?ooo`D00000;P3oool010000000oooo0?ooo`00
000^0?ooo`040000003oool0oooo000002h0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0040oooo000K0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo000002l0oooo0`00000`0?ooo`80
0000;`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3oool001/0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0000
0300oooo00<000000?ooo`000000<03oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo
000002h0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0040oooo000K
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02`3oool200000380oooo0P00000`
0?ooo`<00000;`3oool2000002h0oooo0P0000040?ooo`800000103oool001/0oooo0P00000R0?oo
o`030000003oool0oooo0=h0oooo000K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0gP3oool001/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3N0?ooo`006`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0=h0oooo000K0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0gP3oool001@0ooooo`00000=000000006`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000
oooo0000000;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool001/0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool01@3oool001/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`3M0?ooo`006`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0=d0oooo000K0?oo
o`8000008`3oool00`000000oooo0?ooo`3M0?ooo`006`3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0=d0oooo000K0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
g@3oool001/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3L0?ooo`006`3oool2
000002@0oooo00<000000?ooo`3oool0g03oool001/0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`3L0?ooo`006`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0=`0
oooo000K0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0g03oool001/0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`3K0?ooo`006`3oool2000002D0oooo00<00000
0?ooo`3oool0f`3oool001/0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3K0?oo
o`006`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0=/0oooo000K0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0f`3oool001/0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`3K0?ooo`006`3oool2000002H0oooo00<000000?ooo`3oool0fP3oool0
01/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3J0?ooo`006`3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo0=X0oooo0000103oool000000000000000040?ooo`80
00000`3oool4000000<0oooo0P0000050?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0fP3oool000<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3J0?ooo`00
0P3oool3000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`800000
9`3oool00`000000oooo0?ooo`3I0?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000
003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
f@3oool000050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`3I0?ooo`00
0P3oool3000000T0oooo0P0000040?ooo`<00000103oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0=T0oooo000K0?ooo`8000009`3oool00`000000oooo0?ooo`3I0?ooo`006`3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0=P0oooo000K0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0f03oool001/0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`3H0?ooo`006`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0=P0oooo
000K0?ooo`800000:@3oool00`000000oooo0?ooo`3G0?ooo`006`3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo0=L0oooo000K0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0e`3oool001/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3F0?ooo`00
6`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0=H0oooo000K0?ooo`800000:P3o
ool00`000000oooo0?ooo`3F0?ooo`006`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0=D0oooo000K0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0e@3oool001/0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`3E0?ooo`006`3oool2000002`0oooo
00<000000?ooo`3oool0e03oool001/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`3D0?ooo`006`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0=@0oooo00070?oo
o`<00000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0d`3oool000T0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0d`3oool000P0oooo0`00000;0?ooo`03
0000003oool0oooo0080oooo0P00000]0?ooo`030000003oool0oooo0=<0oooo00070?ooo`040000
003oool0oooo000000T0oooo0P0000050?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0dP3oool000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0dP3oool000P0oooo0`0000090?ooo`<00000
103oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0=80oooo000K0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0d@3oool001/0oooo0P00000_0?ooo`030000003oool0
oooo0=40oooo000K0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0d@3oool001/0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3@0?ooo`006`3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo0=00oooo000K0?ooo`800000<03oool00`000000oooo0?oo
o`3@0?ooo`006`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0<l0oooo000K0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0c`3oool001/0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`3>0?ooo`006`3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0<h0oooo000K0?ooo`800000<P3oool00`000000oooo0?ooo`3>0?ooo`006`3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0<d0oooo000K0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0c@3oool001/0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`3<0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0<`0oooo
000K0?ooo`800000=@3oool00`000000oooo0?ooo`3;0?ooo`006`3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0</0oooo000K0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0bP3oool000040?ooo`0000000000000000@0oooo0P0000050?ooo`030000003oool0oooo
0080oooo0P0000050?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0bP3oool000<0
oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0<T0oooo00020?ooo`<0
00002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P00000g0?ooo`03
0000003oool0oooo0<T0oooo00001@3oool000000?ooo`3oool0000000/0oooo00@000000?ooo`3o
ool0oooo0P0000050?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0b03oool00005
0?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`370?ooo`000P3oool30000
00P0oooo100000030?ooo`<00000103oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
0<H0oooo000K0?ooo`800000>P3oool00`000000oooo0?ooo`360?ooo`006`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo0<D0oooo000K0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0a03oool001/0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`33
0?ooo`006`3oool00`000000oooo0?ooo`0m0?ooo`800000``3oool001/0oooo0P0000100?ooo`03
0000003oool0oooo0<00oooo000K0?ooo`030000003oool0oooo0400oooo0P0000300?ooo`006`3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0;d0oooo000K0?ooo`030000003oool0
oooo04<0oooo0P00002m0?ooo`006`3oool00`000000oooo0?ooo`150?ooo`800000^`3oool001/0
oooo0P0000180?ooo`030000003oool0oooo0;P0oooo000K0?ooo`030000003oool0oooo04P0oooo
0P00002h0?ooo`006`3oool00`000000oooo0?ooo`1:0?ooo`800000]P3oool001/0oooo00<00000
0?ooo`3oool0C03oool200000;@0oooo000K0?ooo`800000C`3oool200000;80oooo000K0?ooo`03
0000003oool0oooo0500oooo1000002^0?ooo`006`3oool00`000000oooo0?ooo`1D0?ooo`D00000
Z@3oool000d0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`1I0?ooo`P00000X@3o
ool000l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0H@3ooolD000008d0oooo000?0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`020?ooo`800000MP3ooon6000000L0oooo000?0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo0`3o
ool000l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0o`3oool30?ooo`003P3oool2000000@0oooo0P0000050?ooo`030000003oool0
oooo0?l0oooo0`3oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.07864, 8.22789, \
0.0394728, 0.0106458}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[" Dumped Vibration with Two Characteristic Values", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B = 2\ Sqrt[K\ M] - 1;\)\), "\[IndentingNewLine]", 
    \(solution = DSolve[equ[M, K, B] \[Equal] Qdc, x[t], t]\)}], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \(\(10.`\)\(\[InvisibleSpace]\)\) + \
\[ExponentialE]\^\(\(-0.2440169358562924`\)\ t\)\ C[2]\ Cos[
                0.5232485722375546`\ t] + \
\[ExponentialE]\^\(\(-0.2440169358562924`\)\ t\)\ C[1]\ Sin[
                0.5232485722375546`\ t]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(K = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(M = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(B = 2\ Sqrt[K\ M] - 1;\)\), "\[IndentingNewLine]", 
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] Qdc, x[t], t, 
        GeneratedParameters \[Rule] Con]\)}], "Input"],

Cell[BoxData[
    \({{x[t] \[Rule] \(\(10.`\)\(\[InvisibleSpace]\)\) + 
            0.`\ \[ExponentialE]\^\(\(-0.2440169358562924`\)\ t\)\ Cos[
                0.5232485722375546`\ t] - 
            10.`\ \[ExponentialE]\^\(\(-0.2440169358562924`\)\ t\)\ Sin[
                0.5232485722375546`\ t]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[x[t] /. solution], {t, 0, 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 -0.402597 0.089544 [
[.21429 .03262 -3 -9 ]
[.21429 .03262 3 0 ]
[.40476 .03262 -3 -9 ]
[.40476 .03262 3 0 ]
[.59524 .03262 -3 -9 ]
[.59524 .03262 3 0 ]
[.78571 .03262 -3 -9 ]
[.78571 .03262 3 0 ]
[.97619 .03262 -6 -9 ]
[.97619 .03262 6 0 ]
[.01131 .13467 -6 -4.5 ]
[.01131 .13467 0 4.5 ]
[.01131 .22421 -6 -4.5 ]
[.01131 .22421 0 4.5 ]
[.01131 .31375 -6 -4.5 ]
[.01131 .31375 0 4.5 ]
[.01131 .4033 -6 -4.5 ]
[.01131 .4033 0 4.5 ]
[.01131 .49284 -12 -4.5 ]
[.01131 .49284 0 4.5 ]
[.01131 .58239 -12 -4.5 ]
[.01131 .58239 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .04512 m
.21429 .05137 L
s
[(2)] .21429 .03262 0 1 Mshowa
.40476 .04512 m
.40476 .05137 L
s
[(4)] .40476 .03262 0 1 Mshowa
.59524 .04512 m
.59524 .05137 L
s
[(6)] .59524 .03262 0 1 Mshowa
.78571 .04512 m
.78571 .05137 L
s
[(8)] .78571 .03262 0 1 Mshowa
.97619 .04512 m
.97619 .05137 L
s
[(10)] .97619 .03262 0 1 Mshowa
.125 Mabswid
.07143 .04512 m
.07143 .04887 L
s
.11905 .04512 m
.11905 .04887 L
s
.16667 .04512 m
.16667 .04887 L
s
.2619 .04512 m
.2619 .04887 L
s
.30952 .04512 m
.30952 .04887 L
s
.35714 .04512 m
.35714 .04887 L
s
.45238 .04512 m
.45238 .04887 L
s
.5 .04512 m
.5 .04887 L
s
.54762 .04512 m
.54762 .04887 L
s
.64286 .04512 m
.64286 .04887 L
s
.69048 .04512 m
.69048 .04887 L
s
.7381 .04512 m
.7381 .04887 L
s
.83333 .04512 m
.83333 .04887 L
s
.88095 .04512 m
.88095 .04887 L
s
.92857 .04512 m
.92857 .04887 L
s
.25 Mabswid
0 .04512 m
1 .04512 L
s
.02381 .13467 m
.03006 .13467 L
s
[(6)] .01131 .13467 1 0 Mshowa
.02381 .22421 m
.03006 .22421 L
s
[(7)] .01131 .22421 1 0 Mshowa
.02381 .31375 m
.03006 .31375 L
s
[(8)] .01131 .31375 1 0 Mshowa
.02381 .4033 m
.03006 .4033 L
s
[(9)] .01131 .4033 1 0 Mshowa
.02381 .49284 m
.03006 .49284 L
s
[(10)] .01131 .49284 1 0 Mshowa
.02381 .58239 m
.03006 .58239 L
s
[(11)] .01131 .58239 1 0 Mshowa
.125 Mabswid
.02381 .06303 m
.02756 .06303 L
s
.02381 .08094 m
.02756 .08094 L
s
.02381 .09885 m
.02756 .09885 L
s
.02381 .11676 m
.02756 .11676 L
s
.02381 .15258 m
.02756 .15258 L
s
.02381 .17048 m
.02756 .17048 L
s
.02381 .18839 m
.02756 .18839 L
s
.02381 .2063 m
.02756 .2063 L
s
.02381 .24212 m
.02756 .24212 L
s
.02381 .26003 m
.02756 .26003 L
s
.02381 .27794 m
.02756 .27794 L
s
.02381 .29585 m
.02756 .29585 L
s
.02381 .33166 m
.02756 .33166 L
s
.02381 .34957 m
.02756 .34957 L
s
.02381 .36748 m
.02756 .36748 L
s
.02381 .38539 m
.02756 .38539 L
s
.02381 .42121 m
.02756 .42121 L
s
.02381 .43912 m
.02756 .43912 L
s
.02381 .45703 m
.02756 .45703 L
s
.02381 .47493 m
.02756 .47493 L
s
.02381 .51075 m
.02756 .51075 L
s
.02381 .52866 m
.02756 .52866 L
s
.02381 .54657 m
.02756 .54657 L
s
.02381 .56448 m
.02756 .56448 L
s
.02381 .02721 m
.02756 .02721 L
s
.02381 .00931 m
.02756 .00931 L
s
.02381 .6003 m
.02756 .6003 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .49284 m
.06244 .32198 L
.08255 .24852 L
.10458 .18026 L
.1253 .12751 L
.14415 .08889 L
.16372 .05787 L
.17461 .04445 L
.18466 .03439 L
.19395 .02702 L
.20381 .02115 L
.20891 .01887 L
.2137 .0172 L
.21639 .01645 L
.21895 .01587 L
.22189 .01534 L
.22319 .01516 L
.22459 .015 L
.22594 .01488 L
.22718 .0148 L
.22837 .01475 L
.22962 .01472 L
.23074 .01472 L
.23179 .01473 L
.23294 .01477 L
.23418 .01485 L
.23549 .01495 L
.23692 .0151 L
.23952 .01545 L
.24205 .0159 L
.2444 .01642 L
.25331 .01918 L
.25781 .02105 L
.26278 .02347 L
.28213 .03619 L
.30299 .05523 L
.34413 .10576 L
.38375 .16584 L
.42186 .22929 L
.46242 .29835 L
.50147 .36261 L
.54296 .42529 L
.58294 .47797 L
.62141 .52019 L
.66233 .55534 L
.68269 .56904 L
.70173 .57963 L
.72117 .58829 L
.73962 .59458 L
.74933 .59717 L
Mistroke
.75991 .59945 L
.76953 .60105 L
.77844 .60214 L
.78354 .6026 L
.78621 .60279 L
.78904 .60297 L
.79152 .60309 L
.79423 .60319 L
.79543 .60323 L
.7967 .60326 L
.79791 .60328 L
.79901 .6033 L
.80016 .60331 L
.80139 .60332 L
.80244 .60332 L
.80359 .60331 L
.80483 .6033 L
.80553 .6033 L
.80616 .60329 L
.80741 .60326 L
.80857 .60324 L
.81068 .60317 L
.81299 .60308 L
.81763 .60284 L
.82269 .60249 L
.82818 .602 L
.83812 .60085 L
.85672 .59784 L
.87664 .59351 L
.89769 .58788 L
.93563 .57562 L
.97603 .56062 L
.97619 .56056 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000?0?ooo`030000
003oool0oooo0300oooo1000000c0?ooo`<00000<03oool3000003<0oooo0P00000_0?ooo`D00000
0P3oool2000000@0oooo000?0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0_0?ooo`040000003oool0oooo00000340oooo00@000000?ooo`3oool0
0000<03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3oool000l0
oooo0P00000b0?ooo`030000003oool0oooo0340oooo1@00000`0?ooo`040000003oool0oooo0000
0340oooo00@000000?ooo`3oool00000<03oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00@3oool000l0oooo00<000000?ooo`3oool0<P3oool8000002/0oooo00@00000
0?ooo`3oool00000<@3oool3000003<0oooo0P00000a0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`010?ooo`003`3oool00`000000oooo0?ooo`0`0?ooo`@000001P3o
ool4000002P0oooo00<000000?ooo`000000<P3oool00`000000oooo0?ooo`0a0?ooo`040000003o
ool0oooo00000300oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0040
oooo000?0?ooo`030000003oool0oooo02l0oooo00@000000?ooo`00000000002`3oool00`000000
oooo0?ooo`0V0?ooo`800000<P3oool300000380oooo0P00000`0?ooo`800000103oool2000000@0
oooo000?0?ooo`030000003oool0oooo02d0oooo0P00000@0?ooo`030000003oool0oooo0<`0oooo
000?0?ooo`800000;@3oool00`000000oooo0?ooo`0A0?ooo`800000c03oool000l0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0D0?ooo`800000bP3oool000l0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0G0?ooo`800000b03oool000l0oooo00<000000?ooo`3o
ool0:03oool2000001`0oooo00<000000?ooo`3oool0a@3oool000l0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<@0oooo00080?ooool000006@00
000000l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00D0oooo000?0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`300?ooo`003`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0_`3oool000l0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0;h0oooo000?0?ooo`800000903oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo0;h0oooo000?0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`2m0?ooo`003`3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0_03oool000l0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0;/0oooo000?0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2k0?ooo`003`3o
ool200000200oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2j0?ooo`003`3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0^@3oool0
00l0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
0;P0oooo000?0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`2g0?ooo`003`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0]`3oool000l0oooo0P00000N0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0]P3oool000l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0;D0oooo000?0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`2d0?ooo`003`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0]03oool000l0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0;<0oooo000?0?ooo`8000006`3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0;80oooo000?0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2b0?ooo`003`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0/@3oool000L0
oooo0`0000050?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`2`0?ooo`001`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2`0?ooo`001`3oool010000000oooo
0?ooo`0000040?ooo`<00000603oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0:l0
oooo00070?ooo`<000001@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0[`3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0[P3oool000P0oooo0`000004
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`2]
0?ooo`003`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0[@3oool000l0oooo0P00000G0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0[03oool000l0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo0:/0oooo000?0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`2[0?ooo`003`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool0ZP3oool000l0oooo0P00000E0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0Z@3oool000l0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0:T0oooo000?0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2X0?ooo`003`3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0Z03oool000l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0:L0oooo000?0?oo
o`8000004`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0:H0oooo000?0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`2V0?ooo`00
3`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
Y@3oool000l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo0:D0oooo000?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`2T0?ooo`003`3oool200000180oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`2S0?ooo`003`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool0X`3oool000l0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0:80oooo00090?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0:40oooo0009
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0:40oooo00090?ooo`030000003oool0oooo00<0oooo0`00000?0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0X03oool000X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0X03oool000L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0W`3oool000L0oooo100000040?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`2N0?ooo`003`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0WP3o
ool000l0oooo0P00000?0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0W@3oool0
00l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
09d0oooo000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`2L0?ooo`003`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05l0oooo
00<000000?ooo`3oool0W03oool000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo09/0oooo000?0?ooo`8000003@3oool00`000000oooo0?ooo`1R
0?ooo`030000003oool0oooo09X0oooo000?0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0HP3oool00`000000oooo0?ooo`2J0?ooo`003`3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool0V@3oool000l0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo09T0oooo000?0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`2H0?ooo`003`3oool2
000000`0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`2G0?ooo`003`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0U`3oool000l0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo09H0
oooo000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`2F0?ooo`003`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06T0oooo00<0
00000?ooo`3oool0U@3oool000l0oooo0P00000;0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0U@3oool000l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo09@0oooo000?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0K03oool00`000000oooo0?ooo`2C0?ooo`00203oool2000000D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo09<0oooo00070?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo0980oooo00070?ooo`040000003oool0oooo000000@0oooo0`0000090?ooo`030000
003oool0oooo06d0oooo00<000000?ooo`3oool0TP3oool000P0oooo0P0000050?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`2A0?ooo`001`3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`2@0?ooo`00203oool2000000D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0900oooo000?0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`2?0?ooo`003`3oool2000000T0
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`2?0?ooo`003`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0SP3oool000l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo08d0oooo000?
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`2=
0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07D0oooo00<000000?oo
o`3oool0S03oool000l0oooo0P0000070?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0R`3oool000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo08/0oooo000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0N03o
ool00`000000oooo0?ooo`2:0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool0RP3oool000l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo08T0oooo000?0?ooo`8000001P3oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo08P0oooo000?0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`280?ooo`003`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0Q`3oool000l0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo08H0oooo000?0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`260?oo
o`003`3oool2000000D0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`250?ooo`00
3`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0
Q03oool000l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo08@0oooo00070?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0880oooo00<000000?ooo`3oool0P`3oool000T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0P`3oool000P0
oooo0`0000040?ooo`<000000`3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0880
oooo00070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`240?ooo`030000003oool0oooo0840oooo00070?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0840
oooo00080?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0P03oool000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`270?ooo`030000003oool0oooo07l0oooo000?0?ooo`8000000`3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo07l0oooo000?0?ooo`050000003oool0oooo0?ooo`000000R`3oool0
0`000000oooo0?ooo`1n0?ooo`003`3oool01@000000oooo0?ooo`3oool0000008`0oooo00<00000
0?ooo`3oool0O@3oool000l0oooo00D000000?ooo`3oool0oooo0000002<0?ooo`030000003oool0
oooo07d0oooo000?0?ooo`050000003oool0oooo0?ooo`000000S@3oool00`000000oooo0?ooo`1l
0?ooo`003`3oool200000080oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`1k0?oo
o`003`3oool010000000oooo0?ooo`00002@0?ooo`030000003oool0oooo07X0oooo000?0?ooo`04
0000003oool0oooo00000900oooo00<000000?ooo`3oool0NP3oool000l0oooo00@000000?ooo`3o
ool00000T@3oool00`000000oooo0?ooo`1i0?ooo`003`3oool010000000oooo0?ooo`00002B0?oo
o`030000003oool0oooo07P0oooo000?0?ooo`<00000U03oool00`000000oooo0?ooo`1g0?ooo`00
3`3oool00`000000oooo0000002D0?ooo`030000003oool0oooo07L0oooo000?0?ooo`030000003o
ool0000009D0oooo00<000000?ooo`3oool0MP3oool000l0oooo00<000000?ooo`000000UP3oool0
0`000000oooo0?ooo`1e0?ooo`003`3oool2000009P0oooo00<000000?ooo`3oool0M03oool000l0
oooo0P00002H0?ooo`030000003oool0oooo07@0oooo000?0?ooo`800000V@3oool00`000000oooo
0?ooo`1c0?ooo`003`3oool2000009X0oooo00<000000?ooo`3oool0LP3oool000030?ooo`000000
000000<000000P3oool2000000D0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`1a
0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0700oooo00030?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000W03oool00`000000oooo0?ooo`1_
0?ooo`000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo06h0oooo00030?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo09d0oooo00<00000
0?ooo`3oool0KP3oool00080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`2N0?oo
o`030000003oool0oooo06d0oooo000?0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool0K03oool000l0oooo0P00002Q0?ooo`030000003oool0oooo06/0oooo000?0?ooo`030000003o
ool0oooo0:40oooo00<000000?ooo`3oool0JP3oool000l0oooo00<000000?ooo`3oool0XP3oool0
0`000000oooo0?ooo`1Y0?ooo`003`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo
06P0oooo000?0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0I`3oool000l0oooo
0P00002V0?ooo`030000003oool0oooo06H0oooo000?0?ooo`030000003oool0oooo0:H0oooo0P00
001V0?ooo`003`3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo06<0oooo000?0?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0HP3oool000l0oooo00<000000?ooo`3o
ool0ZP3oool00`000000oooo0?ooo`1Q0?ooo`003`3oool200000:`0oooo00<000000?ooo`3oool0
H03oool000l0oooo00<000000?ooo`3oool0[03oool200000600oooo000?0?ooo`030000003oool0
oooo0:h0oooo00<000000?ooo`3oool0G@3oool000l0oooo00<000000?ooo`3oool0[`3oool00`00
0000oooo0?ooo`1L0?ooo`003`3oool00`000000oooo0?ooo`2`0?ooo`800000D`3oool2000000L0
oooo000?0?ooo`800000/`3oool2000004h0oooo0`0000090?ooo`003`3oool00`000000oooo0?oo
o`2d0?ooo`030000003oool0oooo04T0oooo0P00000<0?ooo`003`3oool00`000000oooo0?ooo`2e
0?ooo`800000AP3oool3000000h0oooo00000`3oool0000000000003000000030?ooo`0000000000
00<000000`3oool00`000000oooo0?ooo`2g0?ooo`800000@@3oool300000140oooo00030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2i0?ooo`80
0000?03oool3000001@0oooo00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool300000;/0oooo0P00000h0?ooo`8000005`3oool000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;d0oooo0P00000c0?ooo`<000006@3o
ool000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0;l0oooo0`00000/0?ooo`@00000703oool00080oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`320?ooo`@000008P3oool600000200oooo000?0?ooo`030000003oool0oooo0<H0
oooo0`00000J0?ooo`D000009P3oool000l0oooo0P00003:0?ooo`D000004@3oool4000002/0oooo
000?0?ooo`030000003oool0oooo0<h0oooo4@00000_0?ooo`003`3oool00`000000oooo0?ooo`3o
0?ooo`l0oooo000?0?ooo`030000003oool0oooo0?l0oooo3`3oool000l0oooo00<000000?ooo`3o
ool0o`3oool?0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo003o0?ooob40oooo003o
0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.584301, 4.39497, \
0.0377504, 0.0401509}}]
}, Closed]],

Cell[BoxData[
    \(\(Quit[];\)\)], "Input"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
WindowSize->{625, 642},
WindowMargins->{{-1, Automatic}, {Automatic, -1}},
ShowSelection->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 98, 4, 52, "Subsection"],

Cell[CellGroupData[{
Cell[1899, 61, 103, 2, 45, "Subsubsection"],
Cell[2005, 65, 31, 0, 29, "Text"],
Cell[2039, 67, 93, 1, 50, "Input"],
Cell[2135, 70, 33, 0, 29, "Text"],
Cell[2171, 72, 89, 1, 50, "Input"],
Cell[2263, 75, 27, 0, 29, "Text"],
Cell[2293, 77, 107, 2, 50, "Input"],
Cell[2403, 81, 46, 0, 29, "Text"],
Cell[2452, 83, 81, 1, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2570, 89, 44, 0, 45, "Subsubsection"],
Cell[2617, 91, 37, 0, 29, "Text"],
Cell[2657, 93, 146, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2840, 101, 59, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[2924, 105, 86, 1, 50, "Input"],
Cell[3013, 108, 253, 5, 79, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3315, 119, 39, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[3379, 123, 144, 2, 70, "Input"],
Cell[3526, 127, 215, 4, 72, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[3778, 136, 442, 9, 170, "Input"],
Cell[4223, 147, 225, 4, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[4485, 156, 82, 1, 50, "Input"],
Cell[4570, 159, 15715, 384, 186, 3254, 226, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20334, 549, 70, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[20429, 553, 148, 2, 70, "Input"],
Cell[20580, 557, 247, 5, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[20864, 567, 289, 6, 110, "Input"],
Cell[21156, 575, 225, 4, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[21418, 584, 82, 1, 50, "Input"],
Cell[21503, 587, 17997, 468, 186, 4149, 292, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[39549, 1061, 73, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[39647, 1065, 148, 2, 70, "Input"],
Cell[39798, 1069, 307, 6, 68, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[40142, 1080, 289, 6, 110, "Input"],
Cell[40434, 1088, 315, 5, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[40786, 1098, 82, 1, 50, "Input"],
Cell[40871, 1101, 20760, 530, 186, 4708, 327, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[61646, 1634, 44, 1, 50, "Input"]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

