(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     56126,       1508]*)
(*NotebookOutlinePosition[     56806,       1531]*)
(*  CellTagsIndexPosition[     56762,       1527]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Note-9"
}], "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Lagrangian and Rayleigh's dissipative function in linear motion system\
\>", "Subsubsection"],

Cell["Kinetic energy:", "Text"],

Cell[BoxData[
    \(\(kineticEnergy[m_, x_] := \((1/2)\)*m*\((D[x[t], t]^2)\);\)\)], "Input"],

Cell["Potential energy:", "Text"],

Cell[BoxData[
    \(\(potentialEnergy[k_, x_] := \((1/2)\)*k*\((x[t]^2)\);\)\)], "Input"],

Cell["Lagrangian:", "Text"],

Cell[BoxData[
    \(\(l[m_, k_, x_] := 
        kineticEnergy[m, x] - potentialEnergy[k, x];\)\)], "Input"],

Cell["Rayleigh dissipative function:", "Text"],

Cell[BoxData[
    \(\(f[b_, x_] := \((1/2)\)*b*\((D[x[t], t]^2)\);\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["System of equations", "Subsubsection"],

Cell["Linear motion system:", "Text"],

Cell[BoxData[
    \(equ[M_, K_, B_] := 
      D[D[l[M, K, x], D[x[t], t]], t] - D[l[M, K, x], x[t]] + 
        D[f[B, x], D[x[t], t]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution of Homogeneous Equation", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solution = DSolve[equ[M, K, B] \[Equal] 0, x[t], t]\)], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \[ExponentialE]\^\(\(\((\(-B\) - \@\(B\^2 - 4\ K\ M\))\
\)\ t\)\/\(2\ M\)\)\ C[
                1] + \[ExponentialE]\^\(\(\((\(-B\) + \@\(B\^2 - 4\ K\ M\))\)\
\ t\)\/\(2\ M\)\)\ C[2]}}\)], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simple Dumping", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B = 2\ Sqrt[K\ M];\)\), "\[IndentingNewLine]", 
    \(solution = DSolve[equ[M, K, B] \[Equal] 0, x[t], t]\)}], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \[ExponentialE]\^\(-\(\(\@\(K\ M\)\ t\)\/M\)\)\ C[
                1] + \[ExponentialE]\^\(-\(\(\@\(K\ M\)\ t\)\/M\)\)\ t\ C[
                2]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(K = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(M = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(Con[1] = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(Con[2] = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(B = 2\ Sqrt[K\ M];\)\), "\[IndentingNewLine]", 
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] 0, x[t], t, 
        GeneratedParameters \[Rule] Con]\)}], "Input"],

Cell[BoxData[
    \({{x[t] \[Rule] 
          0.5`\ \[ExponentialE]\^\(\(-0.5773502691896262`\)\ t\) + 
            1.5`\ \[ExponentialE]\^\(\(-0.5773502691896253`\)\ t\)}}\)], \
"Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[x[t] /. solution], {t, 0, 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.294302 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .16187 -18 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(0.5)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(1.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(2)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .48041 L
.10458 .37544 L
.14415 .2985 L
.18221 .24003 L
.22272 .19097 L
.26171 .15387 L
.30316 .12295 L
.34309 .09968 L
.3815 .08203 L
.42237 .06726 L
.46172 .05611 L
.49955 .04762 L
.53984 .04049 L
.57861 .03509 L
.61984 .03059 L
.65954 .02719 L
.69774 .02461 L
.73838 .02245 L
.77751 .02082 L
.81909 .01946 L
.85916 .01844 L
.89771 .01766 L
.93871 .01701 L
.97619 .01654 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00A`3oool400000380oooo0`00000^0?ooo`<00000<P3oool2000002h0oooo1@0000020?oo
o`800000103oool004L0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0]0?ooo`04
0000003oool0oooo00000300oooo00@000000?ooo`3oool00000;`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00@3oool004P0oooo00<000000?ooo`3oool0<03oool5
000002h0oooo00@000000?ooo`3oool00000<03oool010000000oooo0?ooo`00000_0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`010?ooo`00B@3oool00`000000oooo
0?ooo`0_0?ooo`040000003oool0oooo000002l0oooo0`00000b0?ooo`800000<03oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3oool004L0oooo00@000000?ooo`3o
ool00000<@3oool00`000000oooo0000000`0?ooo`030000003oool0oooo0300oooo00@000000?oo
o`3oool00000;`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3o
ool004P0oooo0P00000c0?ooo`800000<03oool300000340oooo0P00000_0?ooo`800000103oool2
000000@0oooo003o0?ooob40oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo
00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E
0?ooo`030000003oool0oooo0?l0oooo2@3oool000l0ooooo`00000A00000040oooo000E0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool0oooo;00000040?ooo`030000003oool0oooo
00D0oooo000E0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo01l0oooo5P00000`0?ooo`030000003oool0oooo00D0
oooo000E0?ooo`030000003oool0oooo0:D0oooo5@00001>0?ooo`005@3oool00`000000oooo0?oo
o`2J0?ooo`/00000H`3oool001D0oooo00<000000?ooo`3oool0TP3oool8000006h0oooo000E0?oo
o`030000003oool0oooo08`0oooo1P00001f0?ooo`005@3oool00`000000oooo0?ooo`270?ooo`D0
0000O03oool001D0oooo0P0000220?ooo`H00000P@3oool001D0oooo00<000000?ooo`3oool0O03o
ool5000008L0oooo000E0?ooo`030000003oool0oooo07L0oooo1@00002<0?ooo`005@3oool00`00
0000oooo0?ooo`1c0?ooo`@00000T@3oool001D0oooo00<000000?ooo`3oool0K`3oool4000009D0
oooo000E0?ooo`030000003oool0oooo06/0oooo1000002I0?ooo`005@3oool00`000000oooo0?oo
o`1X0?ooo`<00000W@3oool001D0oooo00<000000?ooo`3oool0I@3oool300000:00oooo000E0?oo
o`800000I03oool200000:<0oooo000E0?ooo`030000003oool0oooo0600oooo0`00002U0?ooo`00
5@3oool00`000000oooo0?ooo`1N0?ooo`800000Z03oool001D0oooo00<000000?ooo`3oool0G03o
ool200000:X0oooo000E0?ooo`030000003oool0oooo05X0oooo0P00002/0?ooo`005@3oool00`00
0000oooo0?ooo`1H0?ooo`800000[P3oool001D0oooo00<000000?ooo`3oool0EP3oool200000;00
oooo000E0?ooo`030000003oool0oooo05@0oooo0P00002b0?ooo`005@3oool2000005<0oooo0P00
002d0?ooo`005@3oool00`000000oooo0?ooo`1@0?ooo`800000]P3oool001D0oooo00<000000?oo
o`3oool0CP3oool200000;P0oooo000E0?ooo`030000003oool0oooo04`0oooo0P00002j0?ooo`00
5@3oool00`000000oooo0?ooo`1:0?ooo`800000_03oool001D0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`2l0?ooo`005@3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo0;d0oooo000E0?ooo`030000003oool0oooo04H0oooo0P0000300?ooo`005@3oool2000004H0
oooo00<000000?ooo`3oool0`03oool001D0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`310?ooo`005@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0<80oooo000E
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0``3oool001D0oooo00<000000?oo
o`3oool0@03oool200000<H0oooo000E0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0aP3oool00080oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`370?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`380?ooo`00
00D0oooo0000003oool0oooo0000000;0?ooo`030000003oool0oooo0080oooo0`00000l0?ooo`03
0000003oool0oooo0<T0oooo00001@3oool000000?ooo`3oool0000000T0oooo0P0000050?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0bP3oool000050?ooo`000000oooo0?ooo`00
00002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0b`3oool00080oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`0h0?ooo`800000
cP3oool001D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`3>0?ooo`005@3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0<l0oooo000E0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0d03oool001D0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`3A0?ooo`005@3oool2000003@0oooo00<000000?ooo`3oool0dP3oool001D0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`3C0?ooo`005@3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo0=@0oooo000E0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0e@3oool001D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`3E0?ooo`00
5@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0=H0oooo000E0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0e`3oool001D0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`3H0?ooo`005@3oool2000002d0oooo00<000000?ooo`3oool0f@3oool001D0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3J0?ooo`005@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo0=X0oooo000E0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0f`3oool001D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3L
0?ooo`005@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0=d0oooo000E0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0gP3oool001D0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`3N0?ooo`005@3oool2000002L0oooo00<000000?ooo`3oool0g`3o
ool001D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3P0?ooo`005@3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo0>00oooo000E0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0h@3oool001D0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`3Q0?ooo`005@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0>80oooo000E
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0h`3oool001D0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`3S0?ooo`005@3oool200000280oooo00<000000?ooo`3o
ool0i03oool001D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`3U0?ooo`005@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0>D0oooo000E0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0iP3oool001D0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`3V0?ooo`005@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0>L0
oooo000=0?ooo`D000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0>P0oooo
000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`3X0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`<00000703oool00`000000oooo0?ooo`3Y
0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0j@3oool000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0>X0oooo000>0?ooo`8000001@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0>X0oooo000E0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0j`3o
ool001D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`3[0?ooo`005@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo0>`0oooo000E0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0k03oool001D0oooo0P00000I0?ooo`030000003oool0oooo0>d0oooo
000E0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0k@3oool001D0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`3^0?ooo`005@3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo0>h0oooo000E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0k`3oool001D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3_0?ooo`005@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?00oooo000E0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0l03oool001D0oooo0P00000E0?ooo`030000003oool0oooo
0?40oooo000E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0l@3oool001D0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3b0?ooo`005@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo0?80oooo000E0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0l`3oool001D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3c0?oo
o`005@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?@0oooo000E0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0m03oool001D0oooo0P00000B0?ooo`030000003o
ool0oooo0?@0oooo000E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0m@3oool0
01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3e0?ooo`005@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0?H0oooo000E0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0mP3oool001D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`3g0?ooo`005@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?L0oooo000E0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0m`3oool001D0oooo0P00000>0?ooo`03
0000003oool0oooo0?P0oooo000E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
n03oool001D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3i0?ooo`005@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?T0oooo000E0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0n@3oool001D0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`3j0?ooo`0000<0oooo0000000000000`0000020?ooo`800000103oool2000000D0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3j0?ooo`000`3oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`3k0?ooo`000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo0`00
000:0?ooo`030000003oool0oooo0?/0oooo00030?ooo`030000003oool0oooo00P0oooo0P000005
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o03oool000<0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0o03oool00080oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0?`0oooo000E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
o@3oool001D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3m0?ooo`005@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0?h0oooo000E0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0oP3oool001D0oooo0P0000080?ooo`030000003oool0oooo0?h0
oooo000E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3oool001D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooo`005@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0?l0oooo000E0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0o`3oool10?ooo`005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0
oooo0@3oool001D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`40oooo
000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3oool10?ooo`005@3oool2
000000D0oooo00<000000?ooo`3oool0o`3oool20?ooo`005@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo0P3oool001D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3o0?ooo`80oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
o`3oool30?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo0`3o
ool001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo000E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3oool40?ooo`005@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo103oool001D0oooo0P0000030?ooo`030000
003oool0oooo0?l0oooo103oool001D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?ooo`@0oooo000E0?ooo`050000003oool0oooo0?ooo`000000o`3oool70?ooo`005@3oool0
1@000000oooo0?ooo`3oool000000?l0oooo1`3oool001D0oooo00D000000?ooo`3oool0oooo0000
003o0?ooo`L0oooo000E0?ooo`040000003oool0oooo00000?l0oooo203oool001D0oooo00@00000
0?ooo`3oool00000o`3oool80?ooo`005@3oool010000000oooo0?ooo`00003o0?ooo`P0oooo000E
0?ooo`<00000o`3oool90?ooo`005@3oool00`000000oooo0000003o0?ooo`T0oooo000E0?ooo`03
0000003oool000000?l0oooo2@3oool001D0oooo00<000000?ooo`000000o`3oool90?ooo`005@3o
ool200000?l0oooo2P3oool001D0oooo0P00003o0?ooo`X0oooo000=0?ooo`@00000103oool20000
0?l0oooo2P3oool000d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooo`T0
oooo000>0?ooo`030000003oool0oooo00@0oooo0`00003o0?ooo`T0oooo000?0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0o`3oool90?ooo`003@3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0?l0oooo2@3oool000h0oooo0P0000050?ooo`030000003oool0
oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.829852, -0.15494, \
0.0386179, 0.012497}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simple Dumping with Two Characteristic Values", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B = 1 + 2\ Sqrt[K\ M];\)\), "\[IndentingNewLine]", 
    \(solution = DSolve[equ[M, K, B] \[Equal] 0, x[t], t]\)}], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \[ExponentialE]\^\(\(-1.6149642927103738`\)\ t\)\ C[
                1] + \[ExponentialE]\^\(\(-0.2064029123355441`\)\ t\)\ C[
                2]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(K = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(M = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(Con[1] = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(Con[2] = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(B = 1 + 2\ Sqrt[K\ M];\)\), "\[IndentingNewLine]", 
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] 0, x[t], t, 
        GeneratedParameters \[Rule] Con]\)}], "Input"],

Cell[BoxData[
    \({{x[t] \[Rule] 
          0.5`\ \[ExponentialE]\^\(\(-1.6149642927103738`\)\ t\) + 
            1.5`\ \[ExponentialE]\^\(\(-0.2064029123355441`\)\ t\)}}\)], \
"Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[x[t] /. solution], {t, 0, 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.294302 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .16187 -18 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .30902 -6 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16187 m
.03006 .16187 L
s
[(0.5)] .01131 .16187 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(1)] .01131 .30902 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(1.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(2)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04262 .5455 L
.06244 .49714 L
.08426 .45476 L
.10458 .42268 L
.14264 .37556 L
.18163 .33842 L
.22307 .30637 L
.263 .28014 L
.30142 .25792 L
.34228 .23676 L
.38164 .21833 L
.41947 .20217 L
.45976 .18642 L
.49853 .17255 L
.53975 .15904 L
.57946 .14713 L
.61766 .13661 L
.6583 .12632 L
.69743 .11725 L
.73901 .10841 L
.77908 .10062 L
.81763 .09373 L
.85863 .08701 L
.89812 .08108 L
.93609 .07584 L
.97619 .07075 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00A`3oool400000380oooo0`00000^0?ooo`<00000<P3oool2000002h0oooo1@0000020?oo
o`800000103oool004L0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0]0?ooo`04
0000003oool0oooo00000300oooo00@000000?ooo`3oool00000;`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool00@3oool004P0oooo00<000000?ooo`3oool0<03oool5
000002h0oooo00@000000?ooo`3oool00000<03oool010000000oooo0?ooo`00000_0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`010?ooo`00B@3oool00`000000oooo
0?ooo`0_0?ooo`040000003oool0oooo000002l0oooo0`00000b0?ooo`800000<03oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3oool004L0oooo00@000000?ooo`3o
ool00000<@3oool00`000000oooo0000000`0?ooo`030000003oool0oooo0300oooo00@000000?oo
o`3oool00000;`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3o
ool004P0oooo0P00000c0?ooo`800000<03oool300000340oooo0P00000_0?ooo`800000103oool2
000000@0oooo003o0?ooob40oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo
00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E
0?ooo`030000003oool0oooo0?l0oooo2@3oool000l0ooooo`00000A00000040oooo000E0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`00
5@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
1@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o
0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<000000?ooo`3o
ool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`800000o`3o
ool:0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo
0?l0oooo2@3oool001D0oooo00<000000?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo
0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool001D0oooo00<00000
0?ooo`3oool0o`3oool90?ooo`005@3oool00`000000oooo0?ooo`3n0?ooo`<000001`3oool001D0
oooo0P00003i0?ooo`H000002P3oool001D0oooo00<000000?ooo`3oool0l@3oool700000100oooo
000E0?ooo`030000003oool0oooo0>T0oooo2000000G0?ooo`005@3oool00`000000oooo0?ooo`3S
0?ooo`H000007`3oool001D0oooo00<000000?ooo`3oool0f`3oool8000002D0oooo000E0?ooo`03
0000003oool0oooo0=<0oooo2000000]0?ooo`005@3oool00`000000oooo0?ooo`3=0?ooo`H00000
=@3oool001D0oooo00<000000?ooo`3oool0b03oool5000003/0oooo000E0?ooo`800000``3oool6
00000400oooo000E0?ooo`030000003oool0oooo0;h0oooo100000160?ooo`005@3oool00`000000
oooo0?ooo`2j0?ooo`@00000BP3oool001D0oooo00<000000?ooo`3oool0]P3oool4000004h0oooo
000E0?ooo`030000003oool0oooo0;80oooo1000001B0?ooo`005@3oool00`000000oooo0?ooo`2]
0?ooo`D00000EP3oool001D0oooo00<000000?ooo`3oool0Z@3oool4000005/0oooo000E0?ooo`03
0000003oool0oooo0:D0oooo1000001O0?ooo`005@3oool200000:80oooo1000001S0?ooo`005@3o
ool00`000000oooo0?ooo`2M0?ooo`@00000I`3oool001D0oooo00<000000?ooo`3oool0VP3oool3
000006/0oooo000E0?ooo`030000003oool0oooo09H0oooo1000001^0?ooo`005@3oool00`000000
oooo0?ooo`2C0?ooo`<00000LP3oool001D0oooo00<000000?ooo`3oool0S`3oool4000007D0oooo
00020?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo08/0oooo1000
001i0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0R03oool3000007d0oooo00001@3oool000000?ooo`3oool0000000/0oooo
00<000000?ooo`3oool00P3oool3000008D0oooo0`0000200?ooo`0000D0oooo0000003oool0oooo
000000090?ooo`8000001@3oool00`000000oooo0?ooo`230?ooo`800000P`3oool000050?ooo`00
0000oooo0?ooo`0000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0800oooo
0`0000250?ooo`000P3oool2000000X0oooo0`0000040?ooo`030000003oool0oooo07d0oooo0`00
00280?ooo`005@3oool00`000000oooo0?ooo`1k0?ooo`800000R`3oool001D0oooo00<000000?oo
o`3oool0N03oool3000008d0oooo000E0?ooo`030000003oool0oooo07H0oooo0P00002@0?ooo`00
5@3oool00`000000oooo0?ooo`1c0?ooo`<00000TP3oool001D0oooo0P00001a0?ooo`<00000U@3o
ool001D0oooo00<000000?ooo`3oool0KP3oool2000009P0oooo000E0?ooo`030000003oool0oooo
06/0oooo0`00002J0?ooo`005@3oool00`000000oooo0?ooo`1X0?ooo`<00000W@3oool001D0oooo
00<000000?ooo`3oool0I@3oool300000:00oooo000E0?ooo`030000003oool0oooo06<0oooo0P00
002S0?ooo`005@3oool00`000000oooo0?ooo`1P0?ooo`<00000Y@3oool001D0oooo00<000000?oo
o`3oool0GP3oool200000:P0oooo000E0?ooo`800000G@3oool200000:X0oooo000E0?ooo`030000
003oool0oooo05X0oooo0P00002/0?ooo`005@3oool00`000000oooo0?ooo`1H0?ooo`800000[P3o
ool001D0oooo00<000000?ooo`3oool0EP3oool200000;00oooo000E0?ooo`030000003oool0oooo
05@0oooo0P00002b0?ooo`005@3oool00`000000oooo0?ooo`1B0?ooo`800000]03oool001D0oooo
00<000000?ooo`3oool0D03oool200000;H0oooo000E0?ooo`030000003oool0oooo04h0oooo0P00
002h0?ooo`005@3oool2000004d0oooo0P00002j0?ooo`005@3oool00`000000oooo0?ooo`1:0?oo
o`800000_03oool001D0oooo00<000000?ooo`3oool0B03oool200000;h0oooo000E0?ooo`030000
003oool0oooo04H0oooo0P0000300?ooo`005@3oool00`000000oooo0?ooo`140?ooo`800000`P3o
ool001D0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`320?ooo`005@3oool00`00
0000oooo0?ooo`110?ooo`800000a@3oool001D0oooo00<000000?ooo`3oool0?`3oool200000<L0
oooo000E0?ooo`800000?`3oool00`000000oooo0?ooo`370?ooo`005@3oool00`000000oooo0?oo
o`0l0?ooo`800000bP3oool001D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3:
0?ooo`005@3oool00`000000oooo0?ooo`0i0?ooo`800000c@3oool001D0oooo00<000000?ooo`3o
ool0=`3oool200000<l0oooo000E0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
c`3oool000d0oooo1@0000030?ooo`030000003oool0oooo03@0oooo0P00003B0?ooo`003`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0dP3oool0
00l0oooo00<000000?ooo`3oool00`3oool300000380oooo00<000000?ooo`3oool0d`3oool000l0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0`0?ooo`800000eP3oool000l0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0=H0oooo
000>0?ooo`8000001@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0=L0oooo000E
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0f03oool001D0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`3I0?ooo`005@3oool00`000000oooo0?ooo`0Z0?ooo`80
0000g03oool001D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3L0?ooo`005@3o
ool2000002T0oooo00<000000?ooo`3oool0g@3oool001D0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`3N0?ooo`005@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
0=l0oooo000E0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0h03oool001D0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3Q0?ooo`005@3oool00`000000oooo0?oo
o`0R0?ooo`800000i03oool001D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3T
0?ooo`005@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0>D0oooo000E0?ooo`80
0000803oool00`000000oooo0?ooo`3V0?ooo`005@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0>L0oooo000E0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0j03o
ool001D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`3Y0?ooo`005@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0>X0oooo000E0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0jP3oool001D0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`3[0?ooo`005@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0>`0oooo000E
0?ooo`8000006@3oool00`000000oooo0?ooo`3]0?ooo`005@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0>d0oooo000E0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0kP3oool001D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3_0?ooo`005@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?00oooo000E0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0l03oool001D0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`3a0?ooo`005@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?80
oooo000E0?ooo`8000004`3oool00`000000oooo0?ooo`3c0?ooo`005@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0?<0oooo000E0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0m03oool001D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3e0?oo
o`005@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?D0oooo000E0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0mP3oool000030?ooo`000000000000<000000P3o
ool2000000@0oooo0P0000050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0m`3o
ool000<0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0m`3oool000<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`<000003@3oool00`000000oooo0?ooo`3h0?ooo`000`3oool00`00
0000oooo0?ooo`080?ooo`8000001@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0?T0oooo00030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0?T0oooo00020?ooo`8000002P3oool3000000@0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3j0?ooo`005@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0?X0oooo000E0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0n`3oool001D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3k0?oo
o`005@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0?`0oooo000E0?ooo`800000
2P3oool00`000000oooo0?ooo`3l0?ooo`005@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0?d0oooo000E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o@3oool0
01D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3n0?ooo`005@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0?h0oooo000E0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0o`3oool001D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo0@3oool0
01D0oooo0P0000060?ooo`030000003oool0oooo0?l0oooo0@3oool001D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3o0?ooo`40oooo000E0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0o`3oool20?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0oooo0P3oool001D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o
0?ooo`80oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool30?oo
o`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo0`3oool001D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooo`@0oooo000E0?ooo`8000000`3o
ool00`000000oooo0?ooo`3o0?ooo`@0oooo000E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0o`3oool40?ooo`005@3oool01@000000oooo0?ooo`3oool000000?l0oooo1`3oool0
01D0oooo00D000000?ooo`3oool0oooo0000003o0?ooo`L0oooo000E0?ooo`050000003oool0oooo
0?ooo`000000o`3oool70?ooo`005@3oool010000000oooo0?ooo`00003o0?ooo`P0oooo000E0?oo
o`040000003oool0oooo00000?l0oooo203oool001D0oooo00@000000?ooo`3oool00000o`3oool8
0?ooo`005@3oool300000?l0oooo2@3oool001D0oooo00<000000?ooo`000000o`3oool90?ooo`00
5@3oool00`000000oooo0000003o0?ooo`T0oooo000E0?ooo`030000003oool000000?l0oooo2@3o
ool001D0oooo0P00003o0?ooo`X0oooo000E0?ooo`800000o`3oool:0?ooo`003@3oool4000000@0
oooo0P00003o0?ooo`X0oooo000=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
o`3oool90?ooo`003P3oool00`000000oooo0?ooo`040?ooo`<00000o`3oool90?ooo`003`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2@3oool000d0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`T0oooo000>0?ooo`8000001@3oool00`00
0000oooo0?ooo`3o0?ooo`T0oooo000E0?ooo`030000003oool0oooo0?l0oooo2@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.829852, -0.15494, \
0.0386179, 0.012497}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[" Dumped Vibration with Two Characteristic Values", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B = 2\ Sqrt[K\ M] - 1;\)\), "\[IndentingNewLine]", 
    \(solution = DSolve[equ[M, K, B] \[Equal] 0, x[t], t]\)}], "Input"],

Cell[BoxData[
    \({{x[
            t] \[Rule] \[ExponentialE]\^\(\(-0.2440169358562924`\)\ t\)\ C[
                2]\ Cos[
                0.5232485722375546`\ t] + \
\[ExponentialE]\^\(\(-0.2440169358562924`\)\ t\)\ C[1]\ Sin[
                0.5232485722375546`\ t]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(K = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(M = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(Con[1] = 0.5;\)\), "\[IndentingNewLine]", 
    \(\(Con[2] = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(B = 2\ Sqrt[K\ M] - 1;\)\), "\[IndentingNewLine]", 
    \(solution = 
      DSolve[equ[M, K, B] \[Equal] 0, x[t], t, 
        GeneratedParameters \[Rule] Con]\)}], "Input"],

Cell[BoxData[
    \({{x[t] \[Rule] 
          1.5`\ \[ExponentialE]\^\(\(-0.2440169358562924`\)\ t\)\ Cos[
                0.5232485722375546`\ t] + 
            0.5`\ \[ExponentialE]\^\(\(-0.2440169358562924`\)\ t\)\ Sin[
                0.5232485722375546`\ t]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[x[t] /. solution], {t, 0, 10}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.125887 0.318288 [
[.21429 .11339 -3 -9 ]
[.21429 .11339 3 0 ]
[.40476 .11339 -3 -9 ]
[.40476 .11339 3 0 ]
[.59524 .11339 -3 -9 ]
[.59524 .11339 3 0 ]
[.78571 .11339 -3 -9 ]
[.78571 .11339 3 0 ]
[.97619 .11339 -6 -9 ]
[.97619 .11339 6 0 ]
[.01131 .04632 -30 -4.5 ]
[.01131 .04632 0 4.5 ]
[.01131 .20546 -24 -4.5 ]
[.01131 .20546 0 4.5 ]
[.01131 .28503 -18 -4.5 ]
[.01131 .28503 0 4.5 ]
[.01131 .3646 -24 -4.5 ]
[.01131 .3646 0 4.5 ]
[.01131 .44417 -6 -4.5 ]
[.01131 .44417 0 4.5 ]
[.01131 .52375 -24 -4.5 ]
[.01131 .52375 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .12589 m
.21429 .13214 L
s
[(2)] .21429 .11339 0 1 Mshowa
.40476 .12589 m
.40476 .13214 L
s
[(4)] .40476 .11339 0 1 Mshowa
.59524 .12589 m
.59524 .13214 L
s
[(6)] .59524 .11339 0 1 Mshowa
.78571 .12589 m
.78571 .13214 L
s
[(8)] .78571 .11339 0 1 Mshowa
.97619 .12589 m
.97619 .13214 L
s
[(10)] .97619 .11339 0 1 Mshowa
.125 Mabswid
.07143 .12589 m
.07143 .12964 L
s
.11905 .12589 m
.11905 .12964 L
s
.16667 .12589 m
.16667 .12964 L
s
.2619 .12589 m
.2619 .12964 L
s
.30952 .12589 m
.30952 .12964 L
s
.35714 .12589 m
.35714 .12964 L
s
.45238 .12589 m
.45238 .12964 L
s
.5 .12589 m
.5 .12964 L
s
.54762 .12589 m
.54762 .12964 L
s
.64286 .12589 m
.64286 .12964 L
s
.69048 .12589 m
.69048 .12964 L
s
.7381 .12589 m
.7381 .12964 L
s
.83333 .12589 m
.83333 .12964 L
s
.88095 .12589 m
.88095 .12964 L
s
.92857 .12589 m
.92857 .12964 L
s
.25 Mabswid
0 .12589 m
1 .12589 L
s
.02381 .04632 m
.03006 .04632 L
s
[(-0.25)] .01131 .04632 1 0 Mshowa
.02381 .20546 m
.03006 .20546 L
s
[(0.25)] .01131 .20546 1 0 Mshowa
.02381 .28503 m
.03006 .28503 L
s
[(0.5)] .01131 .28503 1 0 Mshowa
.02381 .3646 m
.03006 .3646 L
s
[(0.75)] .01131 .3646 1 0 Mshowa
.02381 .44417 m
.03006 .44417 L
s
[(1)] .01131 .44417 1 0 Mshowa
.02381 .52375 m
.03006 .52375 L
s
[(1.25)] .01131 .52375 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1.5)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .06223 m
.02756 .06223 L
s
.02381 .07814 m
.02756 .07814 L
s
.02381 .09406 m
.02756 .09406 L
s
.02381 .10997 m
.02756 .10997 L
s
.02381 .1418 m
.02756 .1418 L
s
.02381 .15772 m
.02756 .15772 L
s
.02381 .17363 m
.02756 .17363 L
s
.02381 .18954 m
.02756 .18954 L
s
.02381 .22137 m
.02756 .22137 L
s
.02381 .23729 m
.02756 .23729 L
s
.02381 .2532 m
.02756 .2532 L
s
.02381 .26912 m
.02756 .26912 L
s
.02381 .30095 m
.02756 .30095 L
s
.02381 .31686 m
.02756 .31686 L
s
.02381 .33277 m
.02756 .33277 L
s
.02381 .34869 m
.02756 .34869 L
s
.02381 .38052 m
.02756 .38052 L
s
.02381 .39643 m
.02756 .39643 L
s
.02381 .41235 m
.02756 .41235 L
s
.02381 .42826 m
.02756 .42826 L
s
.02381 .46009 m
.02756 .46009 L
s
.02381 .476 m
.02756 .476 L
s
.02381 .49192 m
.02756 .49192 L
s
.02381 .50783 m
.02756 .50783 L
s
.02381 .53966 m
.02756 .53966 L
s
.02381 .55558 m
.02756 .55558 L
s
.02381 .57149 m
.02756 .57149 L
s
.02381 .5874 m
.02756 .5874 L
s
.02381 .0304 m
.02756 .0304 L
s
.02381 .01449 m
.02756 .01449 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.03279 .59956 L
.04262 .59407 L
.06244 .57898 L
.08426 .55691 L
.10458 .53202 L
.14357 .47543 L
.18502 .4073 L
.22495 .33888 L
.26336 .27436 L
.30423 .21045 L
.34358 .15589 L
.38141 .11137 L
.4217 .07336 L
.46047 .04613 L
.48161 .03507 L
.5017 .02691 L
.51128 .0238 L
.5215 .02102 L
.53108 .0189 L
.53989 .01734 L
.55018 .016 L
.55559 .01549 L
.55835 .01528 L
.5613 .01509 L
.5639 .01496 L
.56628 .01486 L
.56742 .01483 L
.56866 .01479 L
.56983 .01477 L
.57092 .01475 L
.57218 .01473 L
.57285 .01472 L
.57358 .01472 L
.57429 .01472 L
.57505 .01472 L
.5757 .01472 L
.5764 .01472 L
.57767 .01473 L
.57838 .01474 L
.57903 .01475 L
.58029 .01478 L
.58147 .01481 L
.58378 .01488 L
.58632 .01498 L
.59146 .01527 L
.59589 .01559 L
.60066 .01602 L
.61153 .0173 L
.62146 .01881 L
Mistroke
.64048 .02252 L
.66122 .02767 L
.70191 .04035 L
.7411 .05475 L
.78273 .07111 L
.82285 .08688 L
.86145 .10125 L
.90251 .11503 L
.94205 .1264 L
.97619 .13453 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`008@3oool00`000000oooo0?ooo`3l0?ooo`008@3oool00`000000oooo
0?ooo`3l0?ooo`008@3oool00`000000oooo0?ooo`3l0?ooo`008@3oool00`000000oooo0?ooo`3l
0?ooo`008@3oool2000008P0oooo2`00001Z0?ooo`008@3oool00`000000oooo0?ooo`200?ooo`L0
00002`3oool900000640oooo000Q0?ooo`030000003oool0oooo07d0oooo0`00000K0?ooo`@00000
G@3oool00240oooo00<000000?ooo`3oool0N03oool500000280oooo0P00001K0?ooo`008@3oool2
000007L0oooo0P00000Y0?ooo`<00000F03oool00240oooo00<000000?ooo`3oool0M03oool20000
02h0oooo1000001D0?ooo`00203oool2000000@0oooo0P0000030?ooo`@000000`3oool2000000D0
oooo00<000000?ooo`3oool0LP3oool2000003@0oooo1000001@0?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`1`0?ooo`800000>P3oool3000004d0oooo00070?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`800000K`3oool20000
03l0oooo0P00001;0?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0K03oool20000
04<0oooo0`0000180?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo04H0oooo0P0000160?ooo`00203oool2000000X0oooo0P0000040?ooo`<00000103oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo04T0oooo0`0000130?ooo`008@3oool00`000000
oooo0?ooo`1X0?ooo`800000C`3oool300000400oooo000Q0?ooo`800000J03oool00`000000oooo
0?ooo`1B0?ooo`800000?P3oool00240oooo00<000000?ooo`3oool0I@3oool2000005L0oooo0`00
000k0?ooo`008@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo05X0oooo0`00000h
0?ooo`008@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo05h0oooo0P00000f0?oo
o`008@3oool2000006<0oooo00<000000?ooo`3oool0H@3oool3000003<0oooo000Q0?ooo`030000
003oool0oooo02`0oooo1000000`0?ooo`<00000;03oool300000300oooo0P0000050?ooo`800000
903oool500000080oooo0P0000040?ooo`008@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo0340oooo0P00000]0?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool0
00001P3oool3000002<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0040oooo000Q0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;P3oool5000002`0
oooo00@000000?ooo`3oool00000;P3oool010000000oooo0?ooo`0000090?ooo`8000008@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3oool00240oooo0P00000_
0?ooo`030000003oool0oooo02d0oooo00@000000?ooo`3oool00000;@3oool300000300oooo0P00
000<0?ooo`<000007P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0@3oool00240oooo00<000000?ooo`3oool0;03oool010000000oooo0?ooo`00000]0?ooo`050000
003oool000000?ooo`000000;P3oool00`000000oooo0?ooo`0^0?ooo`040000003oool0oooo0000
00h0oooo0P00000L0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`01
0?ooo`008@3oool00`000000oooo0?ooo`0]0?ooo`800000;@3oool010000000oooo0?ooo`3oool2
000002h0oooo0`00000_0?ooo`8000004@3oool3000001P0oooo0P0000040?ooo`800000103oool0
0240oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1j0?ooo`@00000803oool00240
oooo0P00001K0?ooo`030000003oool0oooo07l0oooo1000000L0?ooo`008@3oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo08@0oooo0`00000I0?ooo`008@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo08P0oooo0`00000F0?ooo`008@3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo08`0oooo1000000B0?ooo`006`3ooooo000000H00000000Q0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool400000080oooo00<000000?oo
o`3oool01@3oool00240oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo02`0oooo0`0000070?ooo`008@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0:D0oooo000Q0?ooo`800000E03oool00`000000oooo0?ooo`2V0?ooo`008@3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0:L0oooo000Q0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0Y`3oool00240oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`2X0?ooo`008@3oool200000540oooo00<000000?ooo`3oool0Z@3oool00240oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`2Z0?ooo`008@3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0:X0oooo000Q0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0Z`3oool00240oooo0P00001>0?ooo`030000003oool0oooo0:`0oooo000Q0?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool0[@3oool00240oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`2]0?ooo`008@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo0:h0oooo000Q0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0[`3oool00240
oooo0P00001;0?ooo`030000003oool0oooo0:l0oooo000Q0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0/03oool000P0oooo0P0000040?ooo`8000000`3oool4000000<0oooo0P00
00050?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0/@3oool000L0oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2b0?ooo`001`3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool2000004P0oooo
00<000000?ooo`3oool0/P3oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0;<0oooo
00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0]03oool000P0oooo
0P00000:0?ooo`800000103oool3000000@0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`2d0?ooo`008@3oool2000004D0oooo00<000000?ooo`3oool0]@3oool00240oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`2f0?ooo`008@3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo0;H0oooo000Q0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0]`3oool00240oooo0P0000120?ooo`030000003oool0oooo0;P0oooo000Q0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0^03oool00240oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`2i0?ooo`008@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
0;T0oooo000Q0?ooo`800000@03oool00`000000oooo0?ooo`2j0?ooo`008@3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo0;/0oooo000Q0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0^`3oool00240oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`2l
0?ooo`008@3oool2000003d0oooo00<000000?ooo`3oool0_@3oool00240oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`2m0?ooo`003P3oool2000000@0oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0;h0oooo000=0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo0;l0oooo000=0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3o
ool00P3oool2000003/0oooo00<000000?ooo`3oool0_`3oool000d0oooo00@000000?ooo`3oool0
00002@3oool2000000D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`300?ooo`00
3@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`310?ooo`003P3oool2000000X0oooo0`0000040?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0`@3oool00240oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`320?ooo`008@3oool2000003P0oooo00<000000?ooo`3oool0`P3oool0
0240oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`330?ooo`008@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo0<@0oooo000Q0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0a03oool00240oooo0P00000e0?ooo`030000003oool0oooo0<D0oooo000Q
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0aP3oool00240oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`360?ooo`008@3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0<L0oooo000Q0?ooo`800000<`3oool00`000000oooo0?ooo`370?ooo`008@3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0<P0oooo000Q0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool0b@3oool00240oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`390?ooo`008@3oool200000300oooo00<000000?ooo`3oool0bP3oool00240oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3:0?ooo`00203oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0b`3oool000L0oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0</0oooo00070?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`800000;P3oool00`000000oooo0?ooo`3<0?ooo`001`3o
ool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo0<`0oooo00070?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0c@3oool000P0oooo0P0000090?ooo`@000000`3oool3000000@0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`3>0?ooo`008@3oool2000002`0oooo
00<000000?ooo`3oool0cP3oool00240oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`3?0?ooo`008@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0<l0oooo000Q0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0d03oool00240oooo0P00000Z0?ooo`03
0000003oool0oooo0=00oooo000Q0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
d@3oool00240oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3A0?ooo`008@3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0=80oooo000Q0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0d`3oool00240oooo0P00000W0?ooo`030000003oool0oooo0=<0
oooo000Q0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0e03oool00240oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`3D0?ooo`008@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0=D0oooo000Q0?ooo`800000903oool00`000000oooo0?ooo`3F0?oo
o`008@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0=H0oooo000I0?ooo`D00000
0`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0=L0oooo000K0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`3H0?ooo`006`3oool0
0`000000oooo0?ooo`030?ooo`8000008P3oool00`000000oooo0?ooo`3H0?ooo`006`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0f@3oool001/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0=T0
oooo000J0?ooo`8000001@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0=X0oooo
000Q0?ooo`8000007`3oool00`000000oooo0?ooo`3K0?ooo`008@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0=/0oooo000Q0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0g03oool00240oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3L0?ooo`00
8@3oool2000001d0oooo00<000000?ooo`3oool0g@3oool00240oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`3N0?ooo`008@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo0=h0oooo000Q0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0g`3oool00240
oooo0P00000J0?ooo`030000003oool0oooo0>00oooo000Q0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0h03oool00240oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`3Q0?ooo`008@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0>80oooo000Q0?oo
o`800000603oool00`000000oooo0?ooo`3R0?ooo`008@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0><0oooo000Q0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
i03oool000L0oooo1@0000020?ooo`8000000`3oool4000000<0oooo0P0000050?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0i03oool000T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`3U0?ooo`002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool2000001@0oooo00<000000?ooo`3oool0iP3oool0
00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0>H0oooo00090?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0i`3oool000P0oooo0P00000:0?ooo`800000103oool3000000@0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3X0?ooo`008@3oool200000140oooo
00<000000?ooo`3oool0j@3oool00240oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`3Z0?ooo`008@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0>/0oooo000Q0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0k03oool00240oooo0P00000=0?ooo`03
0000003oool0oooo0>d0oooo000Q0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
kP3oool00240oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3_0?ooo`008@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0?00oooo000Q0?ooo`8000002P3oool00`00
0000oooo0?ooo`3`0?ooo`008@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?40
oooo000Q0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0lP3oool00240oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3c0?ooo`008@3oool2000000D0oooo0P00003f
0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?H0oooo000=0?ooo`D0
00000P3oool2000000@0oooo0P0000050?ooo`040000003oool0oooo0?ooo`800000n@3oool000l0
oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?ooo`040000003oool00000
00000?/0oooo000?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool20000
0?d0oooo000?0?ooo`030000003oool0oooo00P0oooo0P0000050?ooo`030000003oool0oooo0?`0
oooo000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`3l0?ooo`003P3oool2000000X0oooo0`0000040?ooo`030000003oool0oooo0?`0oooo000Q
0?ooo`030000003oool0oooo0?`0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.34313, -0.489863, \
0.0403944, 0.0120868}}]
}, Closed]],

Cell[BoxData[
    \(\(Quit[];\)\)], "Input"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
WindowSize->{654, 639},
WindowMargins->{{-1, Automatic}, {Automatic, 1}},
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 97, 4, 52, "Subsection"],

Cell[CellGroupData[{
Cell[1898, 61, 103, 2, 45, "Subsubsection"],
Cell[2004, 65, 31, 0, 29, "Text"],
Cell[2038, 67, 93, 1, 50, "Input"],
Cell[2134, 70, 33, 0, 29, "Text"],
Cell[2170, 72, 89, 1, 50, "Input"],
Cell[2262, 75, 27, 0, 29, "Text"],
Cell[2292, 77, 107, 2, 50, "Input"],
Cell[2402, 81, 46, 0, 29, "Text"],
Cell[2451, 83, 81, 1, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2569, 89, 44, 0, 45, "Subsubsection"],
Cell[2616, 91, 37, 0, 29, "Text"],
Cell[2656, 93, 146, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2839, 101, 57, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[2921, 105, 84, 1, 50, "Input"],
Cell[3008, 108, 246, 5, 75, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3303, 119, 39, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[3367, 123, 142, 2, 70, "Input"],
Cell[3512, 127, 208, 4, 68, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[3757, 136, 385, 8, 150, "Input"],
Cell[4145, 146, 188, 4, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[4370, 155, 82, 1, 50, "Input"],
Cell[4455, 158, 15478, 379, 186, 3185, 223, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19982, 543, 70, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[20077, 547, 146, 2, 70, "Input"],
Cell[20226, 551, 209, 4, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[20472, 560, 389, 8, 150, "Input"],
Cell[20864, 570, 188, 4, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[21089, 579, 82, 1, 50, "Input"],
Cell[21174, 582, 14872, 373, 186, 3215, 225, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[36095, 961, 73, 0, 45, "Subsubsection"],

Cell[CellGroupData[{
Cell[36193, 965, 146, 2, 70, "Input"],
Cell[36342, 969, 286, 6, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[36665, 980, 389, 8, 150, "Input"],
Cell[37057, 990, 278, 5, 49, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[37372, 1000, 82, 1, 50, "Input"],
Cell[37457, 1003, 18582, 497, 186, 4566, 319, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[56054, 1503, 44, 1, 50, "Input"]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

